@@ -13,23 +13,23 @@ The engine-points table at :samp:`/{XXX}_engine_points` must contain at least on
 from each category below:
 
 1. engine-speed:
-    N        (1/min)
-    N_norm   (1/min)    : normalized against N_idle + (N_rated - N_idle)
-    CM       (m/sec)    : Mean Piston speed
+    N        [1/min]
+    N_norm   [-]        : where N_norm = (N – N_idle) / (N_rated-N_idle)
+    CM       [m/sec]    : Mean Piston speed
 2. work-capability:
-    P        (kW)
-    P_norm   (kW)       : normalized against P_MAX
-    T        (Nm)
-    PME      (bar)
+    P        [kW]
+    P_norm   [-]        : where P_norm = P/P_MAX
+    T        [Nm]
+    BMEP     [bar]
 3. fuel-consumption:
-    FC       (g/h)
-    FC_norm  (g/h)      : normalized against P_MAX
-    PMF      (bar)
+    FC       [g/h]
+    FC_norm  [g/KWh]    : where FC_norm = FC[g/h] / P_MAX [kW]
+    PMF      [bar]
     
 EXAMPLES:
 ---------
 Assuming a CSV-file 'engine.csv' like this:
-        CM,PME,PMF
+        CM,BMEP,PMF
         12,0.14,180
         ...
 
@@ -39,13 +39,13 @@ Assuming a CSV-file 'engine.csv' like this:
     ## ...and if no header existed:
     $ %(prog)s -m fuel=petrol -I engine.csv header@=None
 
-    ## Assume PME column contained normalized-Power in Watts,
+    ## Assume BMEP column contained normalized-Power in Watts,
     #    instead of P in kW:
     $ %(prog)s -m fuel=petrol -I engine.csv  -irenames X X 'Pnorm (w)'
 
     ## Read the same table above but without header-row and
     #    store results into Excel file, 1st sheet:
-    $ %(prog)s -m fuel=petrol -I engine.csv --icolumns CM PME PMF -I engine_map.xlsx sheetname+=0
+    $ %(prog)s -m fuel=petrol -I engine.csv --icolumns CM BMEP PMF -I engine_map.xlsx sheetname+=0
 
     ## Supply as inline-json more model-values required for columns [N, P, FC]
     #    read from <stdin> as json 2D-array of values (no headers).
@@ -153,6 +153,9 @@ def main(argv=None):
     program_name = os.path.basename(sys.argv[0])
     if program_name.endswith('.py'):
         program_name = PROG 
+
+    if sys.version < "3.3":
+        exit("Sorry, only Python 3.3+ is supported!")
         
     if argv is None:
         argv = sys.argv[1:]
@@ -758,14 +761,11 @@ def build_args_parser(program_name, version, desc, epilog):
         """), 
         nargs='?', const=os.getcwd(), metavar='DESTPATH')
     xlusive_group.add_argument('--excelrun', help=dedent("""
-            copies ExcelRunner template files into DESTPATH 
-            (or <current-working-directory> if DESTPATH missing), 
-            and opens the new Excel-file.
+            copies ExcelRunner template files into USERDIR and 
+            open the new Excel-file, to run a batch of experiments.
         """), 
         nargs='?', const=os.getcwd(), metavar='DESTPATH')
     xlusive_group.add_argument('--winmenus', help="Adds shortcuts into Windows StartMenu.", action='store_true')
-    #xlusive_group.add_argument('--docs', help="Builds project's html-documentation and opens browser on it.", action='store_true')
-    
 
     grp_various = parser.add_argument_group('Various', 'Options controlling various other aspects.')
     grp_various.add_argument('-d', "--debug", action="store_true", help=dedent("""
